@@ -2,7 +2,8 @@ from .config import (
     create_task_url,
     app_key,
     get_balance_url,
-    incorrect_captcha_url,
+    incorrect_imagecaptcha_url,
+    incorrect_recaptcha_url,
     HOST,
     PORT,
     RTMQ_USERNAME,
